==> MIDITrail-Ver.1.1.2-MacOSX_src.zip: __MACOSX/MIDITrail/Sources/MIDITrail/._MIDITrailApp.mm <==
    Mac OS X            	   2   y                                         ATTR (r                                com.apple.TextEncoding   utf-8;134217984          ]                                                                                                                                                                                                                                                  
<?xml version="1.0" encoding="UTF-8"?>
<!DOCTYPE plist PUBLIC "-//Apple//DTD PLIST 1.0//EN" "http://www.apple.com/DTDs/PropertyList-1.0.dtd">
<plist version="1.0">
<dict>
	<key>AntiAliasMode</key>
	<integer>0</integer>
	<key>CaretMode</key>
	<true/>
	<key>CaretPoint X</key>
	<integer>1</integer>
	<key>CaretPoint Y</key>
	<integer>64</integer>
	<key>DocWrapMode</key>
	<integer>0</integer>
	<key>FilePath</key>
	<string>/Users/wada/Documents/Xcode Projects/MIDITrail/Sources/MIDITrail/MIDITrailApp.mm</string>
	<key>IndentWidth</key>
	<integer>4</integer>
	<key>LetterCount</key>
	<integer>80</integer>
	<key>ModeName</key>
	<string>C</string>
	<key>PrintForm_FileFont</key>
	<integer>16436</integer>
	<key>PrintForm_FileFontName</key>
	<string>Monaco</string>
	<key>PrintForm_FileFontNameUni</key>
	<string>Osaka−等幅</string>
	<key>PrintForm_FileFontSize</key>
	<real>12</real>
	<key>PrintForm_ForceWordWrap</key>
	<false/>
	<key>PrintForm_LineFont</key>
	<integer>16384</integer>
	<key>PrintForm_LineFontName</key>
	<string>Monaco</string>
	<key>PrintForm_LineFontNameUni</key>
	<string>Osaka</string>
	<key>PrintForm_LineMargin</key>
	<integer>0</integer>
	<key>PrintForm_PageFont</key>
	<integer>16436</integer>
	<key>PrintForm_PageFontName</key>
	<string>Monaco</string>
	<key>PrintForm_PageFontNameUni</key>
	<string>Osaka−等幅</string>
	<key>PrintForm_PageFontSize</key>
	<real>12</real>
	<key>PrintForm_PrintFileName</key>
	<true/>
	<key>PrintForm_PrintFont</key>
	<integer>16436</integer>
	<key>PrintForm_PrintFontName</key>
	<string>Monaco</string>
	<key>PrintForm_PrintFontNameUni</key>
	<string>Osaka−等幅</string>
	<key>PrintForm_PrintFontSize</key>
	<real>12</real>
	<key>PrintForm_PrintLineNumber</key>
	<false/>
	<key>PrintForm_PrintPageNumber</key>
	<true/>
	<key>PrintForm_PrintSeparateLine</key>
	<true/>
	<key>PrintForm_UsePrintFont</key>
	<true/>
	<key>PrintForm_WrapMode</key>
	<integer>0</integer>
	<key>ReturnCode</key>
	<integer>2</integer>
	<key>SelectPoint X</key>
	<integer>1</integer>
	<key>SelectPoint Y</key>
	<integer>64</integer>
	<key>TabWidth</key>
	<integer>4</integer>
	<key>TextEncoding</key>
	<string>UTF-8</string>
	<key>TextFont</key>
	<integer>4</integer>
	<key>TextFontName</key>
	<string>Monaco</string>
	<key>TextFontNameUni</key>
	<string>default</string>
	<key>TextFontSize</key>
	<real>12</real>
	<key>WindowHeight</key>
	<integer>843</integer>
	<key>WindowPosition H</key>
	<integer>899</integer>
	<key>WindowPosition V</key>
	<integer>111</integer>
	<key>WindowWidth</key>
	<integer>756</integer>
	<key>WrapMode</key>
	<integer>0</integer>
	<key>WrapWithLetterCount</key>
	<false/>
	<key>WrapWithLetterCount LetterCount</key>
	<integer>78</integer>
</dict>
</plist>
             @      @   K 0@4 @4 @4 @      M<??     o      C                         #   #  KN      #                     # C  C            #     #   #     o \    #          ]@ 2    F MMKE   MMKP                
    mi Document Preference

==> MIDITrail-Ver.1.1.3a-MacOSX_src.zip: __MACOSX/MIDITrail/Sources/MIDITrail/._MIDITrailApp.mm <==
    Mac OS X            	   2   y                                         ATTR !KM                                com.apple.TextEncoding   utf-8;134217984          ]                                                                                                                                                                                                                                                  
<?xml version="1.0" encoding="UTF-8"?>
<!DOCTYPE plist PUBLIC "-//Apple//DTD PLIST 1.0//EN" "http://www.apple.com/DTDs/PropertyList-1.0.dtd">
<plist version="1.0">
<dict>
	<key>AntiAliasMode</key>
	<integer>0</integer>
	<key>CaretMode</key>
	<true/>
	<key>CaretPoint X</key>
	<integer>51</integer>
	<key>CaretPoint Y</key>
	<integer>315</integer>
	<key>DocWrapMode</key>
	<integer>0</integer>
	<key>FilePath</key>
	<string>/Users/wada/Documents/Xcode Projects/MIDITrail/Sources/MIDITrail/MIDITrailApp.mm</string>
	<key>IndentWidth</key>
	<integer>4</integer>
	<key>LetterCount</key>
	<integer>80</integer>
	<key>ModeName</key>
	<string>C</string>
	<key>PrintForm_FileFont</key>
	<integer>16436</integer>
	<key>PrintForm_FileFontName</key>
	<string>Monaco</string>
	<key>PrintForm_FileFontNameUni</key>
	<string>Osaka−等幅</string>
	<key>PrintForm_FileFontSize</key>
	<real>12</real>
	<key>PrintForm_ForceWordWrap</key>
	<false/>
	<key>PrintForm_LineFont</key>
	<integer>16384</integer>
	<key>PrintForm_LineFontName</key>
	<string>Monaco</string>
	<key>PrintForm_LineFontNameUni</key>
	<string>Osaka</string>
	<key>PrintForm_LineMargin</key>
	<integer>0</integer>
	<key>PrintForm_PageFont</key>
	<integer>16436</integer>
	<key>PrintForm_PageFontName</key>
	<string>Monaco</string>
	<key>PrintForm_PageFontNameUni</key>
	<string>Osaka−等幅</string>
	<key>PrintForm_PageFontSize</key>
	<real>12</real>
	<key>PrintForm_PrintFileName</key>
	<true/>
	<key>PrintForm_PrintFont</key>
	<integer>16436</integer>
	<key>PrintForm_PrintFontName</key>
	<string>Monaco</string>
	<key>PrintForm_PrintFontNameUni</key>
	<string>Osaka−等幅</string>
	<key>PrintForm_PrintFontSize</key>
	<real>12</real>
	<key>PrintForm_PrintLineNumber</key>
	<false/>
	<key>PrintForm_PrintPageNumber</key>
	<true/>
	<key>PrintForm_PrintSeparateLine</key>
	<true/>
	<key>PrintForm_UsePrintFont</key>
	<true/>
	<key>PrintForm_WrapMode</key>
	<integer>0</integer>
	<key>ReturnCode</key>
	<integer>2</integer>
	<key>SelectPoint X</key>
	<integer>51</integer>
	<key>SelectPoint Y</key>
	<integer>315</integer>
	<key>TabWidth</key>
	<integer>4</integer>
	<key>TextEncoding</key>
	<string>UTF-8</string>
	<key>TextFont</key>
	<integer>4</integer>
	<key>TextFontName</key>
	<string>Monaco</string>
	<key>TextFontNameUni</key>
	<string>default</string>
	<key>TextFontSize</key>
	<real>12</real>
	<key>WindowHeight</key>
	<integer>849</integer>
	<key>WindowPosition H</key>
	<integer>656</integer>
	<key>WindowPosition V</key>
	<integer>102</integer>
	<key>WindowWidth</key>
	<integer>878</integer>
	<key>WrapMode</key>
	<integer>0</integer>
	<key>WrapWithLetterCount</key>
	<false/>
	<key>WrapWithLetterCount LetterCount</key>
	<integer>78</integer>
</dict>
</plist>
          3  ;   3  ;   nQ @@4 @4 @4 @      5
\OXO     ;                                87           >7        9                C            87     87       " f _   0          ]@     F MMKE   MMKP                
    mi Document Preference
